Module dynamic

Module dynamic 

Module provides functions to dynamically get audio input (e.g. from mic).

Further, it provides functionality to display the recorded audio side-by-side with a transformation of the audio data, such as a lowpass filter or a frequency spectrum.

**Its recommended to execute all functions here only with --release-flag. Otherwise, the demo might run really slowly.

Modules

live_input
This module enables to record audio and store the latest audio data in a synchronized ringbuffer. See setup_audio_input_loop.
window_top_btm
This module provides the functionality to display a GUI window.