pub struct LiveVisualizer<'a> { /* private fields */ }Expand description
Builder that opens a GUI window showing the live waveform of an audio
input device along with a custom Transform of it.
Example
use audio_visualizer::live::{LiveVisualizer, Transform};
LiveVisualizer::new(Transform::waveform(|samples, _sample_rate| {
samples.iter().map(|s| s * 0.5).collect()
}))
.title("Half amplitude")
.open()
.unwrap();Implementations
Sourceimpl<'a> LiveVisualizer<'a>
impl<'a> LiveVisualizer<'a>
Sourcepub fn new(transform: Transform<'a>) -> Self
pub fn new(transform: Transform<'a>) -> Self
Creates a live visualizer with the given transformation for the lower chart.
Sourcepub fn input(self, input: AudioInput) -> Self
pub fn input(self, input: AudioInput) -> Self
Sets the audio input to record from. Default: the system default input device.
Sourcepub const fn x_range(self, range: Range<f64>) -> Self
pub const fn x_range(self, range: Range<f64>) -> Self
Fixes the x-axis range of the lower chart. Default: the same time
axis as the waveform for Transform::Waveform, automatic bounds
for Transform::Points.
Sourcepub const fn y_range(self, range: Range<f64>) -> Self
pub const fn y_range(self, range: Range<f64>) -> Self
Fixes the y-axis range of the lower chart. See Self::x_range.
Sourcepub fn axis_labels(self, x: impl Into<String>, y: impl Into<String>) -> Self
pub fn axis_labels(self, x: impl Into<String>, y: impl Into<String>) -> Self
Sets the axis labels of the lower chart.
Sourcepub const fn window_size(self, width: f32, height: f32) -> Self
pub const fn window_size(self, width: f32, height: f32) -> Self
Sets the initial window size in logical pixels. Default: 1280x720.